%define api 1.0
%define major 0
%define libname %mklibname mongoc %{api} %{major}
%define develname %mklibname mongoc -d

%define bson_api 1.0
%define bson_major 0
%define bson_libname %mklibname bson %{bson_api} %{bson_major}
%define bson_develname %mklibname bson -d

%bcond_without man

%ifarch x86_64
%define with_tests 0
%else
# See https://jira.mongodb.org/browse/CDRIVER-1186
# 32-bit MongoDB support was officially deprecated
# in MongoDB 3.2, and support is being removed in 3.4.
%define with_tests 0
%endif

Name:      mongo-c-driver
Summary:   Client library written in C for MongoDB
Version:   1.17.3
Release:   %mkrel 1
License:   ASL 2.0
Group:     System/Libraries
URL:       https://github.com/mongodb/mongo-c-driver
Source0:   https://github.com/mongodb/mongo-c-driver/releases/download/%{version}/mongo-c-driver-%{version}.tar.gz
BuildRequires: cmake
BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(libsasl2)
BuildRequires: pkgconfig(icu-uc)
BuildRequires: pkgconfig(snappy)
BuildRequires: pkgconfig(libzstd)
%if %{with_tests}
BuildRequires: mongodb-server
BuildRequires: openssl
%endif
# For man pages
%if %{with man}
BuildRequires: python3-sphinx
%endif

%description
%{name} is a client library written in C for MongoDB.

%package -n %{libname}
Group:		System/Libraries
Summary:	Shared libraries for %{name}
Obsoletes:	%{_lib}mongoc1.0 < 1.8.2-2

%description -n %{libname}
This package contains the shared libraries for %{name}.

%package -n %{develname}
Group:		Development/C
Summary:	Libraries and header files for %{name}
Requires:	%{libname} = %{version}-%{release}

%description -n %{develname}
This package contains the header files and development libraries
for %{name}.

%package -n %{bson_libname}
Group:		System/Libraries
Summary:    Building, parsing, and iterating BSON documents

%description -n %{bson_libname}
This is a library providing useful routines related to building, parsing,
and iterating BSON documents <http://bsonspec.org/>.

%package -n %{bson_develname}
Group:		Development/C
Summary:	Libraries and header files for %{name}
Requires:	%{bson_libname} = %{version}

%description -n %{bson_develname}
This package contains libraries and header files needed for developing
applications that use %{name}.

%prep
%autosetup -p1

%build
%cmake \
    -DENABLE_BSON:STRING=ON \
    -DENABLE_MONGOC:BOOL=ON \
    -DENABLE_SHM_COUNTERS:BOOL=ON \
    -DENABLE_SSL:STRING=OPENSSL \
    -DENABLE_SASL:STRING=CYRUS \
    -DENABLE_ICU:STRING=ON \
    -DENABLE_AUTOMATIC_INIT_AND_CLEANUP:BOOL=OFF \
    -DENABLE_CRYPTO_SYSTEM_PROFILE:BOOL=ON \
    -DENABLE_MAN_PAGES:BOOL=ON \
    -DENABLE_TESTS:BOOL=ON \
    -DENABLE_EXAMPLES:BOOL=OFF \
    -DENABLE_UNINSTALL:BOOL=OFF

%cmake_build

%install
%cmake_install

rm -f %{buildroot}%{_libdir}/*.a
rm -rf %{buildroot}%{_libdir}/cmake/*static*
rm -rf %{buildroot}%{_libdir}/pkgconfig/*static*
rm -rf %{buildroot}%{_datadir}/%{name}

%check
%if %{with_tests}
: Run a server
mkdir dbtest
mongod \
  --journal \
  --ipv6 \
  --unixSocketPrefix /tmp \
  --logpath     $PWD/server.log \
  --pidfilepath $PWD/server.pid \
  --dbpath      $PWD/dbtest \
  --fork

: Run the test suite
ret=0
export MONGOC_TEST_OFFLINE=on
#export MONGOC_TEST_SKIP_SLOW=on

make check || ret=1

: Cleanup
[ -s server.pid ] && kill $(cat server.pid)

exit $ret
%endif

%files
%{_bindir}/mongoc-stat

%files -n %{libname}
%doc COPYING NEWS README.rst THIRD_PARTY_NOTICES
%{_libdir}/libmongoc-%{api}.so.%{major}{,.*}

%files -n %{develname}
%doc src/libmongoc/examples
%{_includedir}/libmongoc-%{api}
%{_libdir}/libmongoc-%{api}.so
%{_libdir}/pkgconfig/libmongoc-%{api}.pc
%{_libdir}/pkgconfig/libmongoc-ssl-%{api}.pc
%{_libdir}/cmake/libmongoc-%{api}
%{_libdir}/cmake/mongoc-%{api}

%if %{with man}
%{_mandir}/man3/mongoc*
%endif

%files -n %{bson_libname}
%{_libdir}/libbson-%{bson_api}.so.%{bson_major}{,.*}

%files -n %{bson_develname}
%doc src/libbson/examples
%{_includedir}/libbson-%{bson_api}
%{_libdir}/libbson-%{api}.so
%{_libdir}/pkgconfig/libbson-%{api}.pc
%{_libdir}/cmake/libbson-%{bson_api}
%{_libdir}/cmake/bson-%{bson_api}
%if %{with man}
%{_mandir}/man3/bson*
%endif


%changelog
* Thu Dec 10 2020 guillomovitch <guillomovitch> 1.17.3-1.mga8
+ Revision: 1655238
- new version 1.17.3

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1.17.2-2.mga8
+ Revision: 1650903
- rebuild for icu

* Fri Nov 06 2020 guillomovitch <guillomovitch> 1.17.2-1.mga8
+ Revision: 1643066
- new version 1.17.2

* Sun Oct 11 2020 guillomovitch <guillomovitch> 1.17.1-1.mga8
+ Revision: 1633438
- new version

* Sat Aug 01 2020 guillomovitch <guillomovitch> 1.17.0-1.mga8
+ Revision: 1610106
- new version 1.17.0

* Wed Jul 01 2020 wally <wally> 1.16.2-3.mga8
+ Revision: 1601123
- fix build with sphinx >= 4.0
- rebuild for icu 67.1

* Sat Apr 04 2020 wally <wally> 1.16.2-2.mga8
+ Revision: 1564480
- rebuild for new icu 66.1

* Fri Feb 28 2020 guillomovitch <guillomovitch> 1.16.2-1.mga8
+ Revision: 1551329
- new version 1.16.2

* Thu Feb 20 2020 umeabot <umeabot> 1.16.1-2.mga8
+ Revision: 1547375
- Mageia 8 Mass Rebuild

* Sat Feb 08 2020 guillomovitch <guillomovitch> 1.16.1-1.mga8
+ Revision: 1488062
- new version 1.16.1

* Sat Jan 25 2020 guillomovitch <guillomovitch> 1.16.0-1.mga8
+ Revision: 1482840
- new version 1.16.0

* Sat Dec 28 2019 guillomovitch <guillomovitch> 1.15.3-1.mga8
+ Revision: 1474598
- new version 1.15.3
+ wally <wally>
- build with new cmake macros

* Fri Nov 08 2019 guillomovitch <guillomovitch> 1.15.2-1.mga8
+ Revision: 1458839
- new version 1.15.2

* Sat Oct 05 2019 daviddavid <daviddavid> 1.15.1-2.mga8
+ Revision: 1449607
- rebuild for new icu 65.1

* Sat Sep 07 2019 guillomovitch <guillomovitch> 1.15.1-1.mga8
+ Revision: 1438110
- new version 1.15.1

* Thu Aug 15 2019 guillomovitch <guillomovitch> 1.15.0-1.mga8
+ Revision: 1429353
- new version 1.15.0

* Tue Aug 13 2019 guillomovitch <guillomovitch> 1.14.1-1.mga8
+ Revision: 1429275
- new version 1.14.1

* Sat Mar 16 2019 guillomovitch <guillomovitch> 1.14.0-1.mga7
+ Revision: 1377994
- new version 1.14.0

* Sat Jan 26 2019 guillomovitch <guillomovitch> 1.13.1-1.mga7
+ Revision: 1361010
- new version 1.13.1

* Fri Jan 11 2019 daviddavid <daviddavid> 1.13.0-2.mga7
+ Revision: 1354741
- rebuild for new icu

* Fri Oct 26 2018 guillomovitch <guillomovitch> 1.13.0-1.mga7
+ Revision: 1325623
- new version 1.13.0

* Sun Sep 23 2018 umeabot <umeabot> 1.9.3-2.mga7
+ Revision: 1299587
- Mageia 7 Mass Rebuild

* Sat Mar 03 2018 guillomovitch <guillomovitch> 1.9.3-1.mga7
+ Revision: 1206231
- new version 1.9.3

* Wed Dec 27 2017 wally <wally> 1.8.2-2.mga7
+ Revision: 1185628
- fix lib pkg name

* Wed Dec 13 2017 guillomovitch <guillomovitch> 1.8.2-1.mga7
+ Revision: 1182509
- new version 1.8.2

* Sat Sep 16 2017 cjw <cjw> 1.6.3-2.mga7
+ Revision: 1154837
- fix build

* Fri Aug 04 2017 guillomovitch <guillomovitch> 1.6.3-1.mga7
+ Revision: 1134821
- imported package mongo-c-driver

